TransF
======

.. currentmodule:: pykeen.models

.. autoclass:: TransF
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TransF.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
